0002-gnu-mate-power-manager-Update-to-1.26.0.patch0000644000175000017460000000257614206265675020215 0ustar  fengusersFrom 68faa9bf4559c1c6c2b9eb890a9fbc5abd048fe3 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:21:13 +0800
Subject: [PATCH 02/34] gnu: mate-power-manager: Update to 1.26.0.

* gnu/packages/mate.scm (mate-power-manager): Update to 1.26.0, add libsecret
as input.
---
 gnu/packages/mate.scm | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 8fc656ede1..9c7686a740 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -97,14 +97,14 @@ (define-public mate-common
 (define-public mate-power-manager
   (package
     (name "mate-power-manager")
-    (version "1.24.2")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-power-manager-" version ".tar.xz"))
        (sha256
-        (base32 "0fni41p3kraxwjnx9l5mdspng0zib1gfdxwlaiyq31mh4g79yjyj"))))
+        (base32 "0ybvwv24g8awxjl2asgvx6l2ghn4limcm48ylha68dkpy3607di6"))))
     (build-system gnu-build-system)
     (native-inputs
      (list pkg-config
@@ -122,6 +122,7 @@ (define-public mate-power-manager
            libnotify
            mate-panel
            libxrandr
+           libsecret
            libcanberra
            upower))
     (home-page "https://mate-desktop.org/")
-- 
2.34.0

0003-gnu-mate-icon-theme-Update-to-1.26.0.patch0000644000175000017460000000215614206265675017474 0ustar  fengusersFrom edc24e8b0d93ad3e0ef2c62d179db40c11c42bc1 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:26:44 +0800
Subject: [PATCH 03/34] gnu: mate-icon-theme: Update to 1.26.0.

* gnu/packages/mate.scm (mate-icon-theme): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 9c7686a740..7d3ad5e3db 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -136,7 +136,7 @@ (define-public mate-power-manager
 (define-public mate-icon-theme
   (package
     (name "mate-icon-theme")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -144,7 +144,7 @@ (define-public mate-icon-theme
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "0a2lz61ivwwcdznmwlmgjr6ipr9sdl5g2czbagnpxkwz8f3m77na"))))
+         "0nha555fhhn0j5wmzmdc7bh93ckzwwdm8mwmzma5whkzslv09xa1"))))
     (build-system gnu-build-system)
     (native-inputs
      (list pkg-config intltool icon-naming-utils))
-- 
2.34.0

0004-gnu-mate-desktop-Update-to-1.26.0.patch0000644000175000017460000000214014206265675017107 0ustar  fengusersFrom 76e3c6482ed6748a84c9a3a468cda98f0db0ddaa Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:29:17 +0800
Subject: [PATCH 04/34] gnu: mate-desktop: Update to 1.26.0.

* gnu/packages/mate.scm (mate-desktop): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 7d3ad5e3db..790ef7fbb3 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -222,14 +222,14 @@ (define-public mate-themes
 (define-public mate-desktop
   (package
     (name "mate-desktop")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-desktop-" version ".tar.xz"))
        (sha256
-        (base32 "1nd1dn8mm1z6x4r68a25q4vzys1a6fmbzc94ss1z1n1872pczs6i"))))
+        (base32 "18sj8smf0b998m5qvki37hxg0agcx7wmgz9z7cwv6v48i2dnnz2z"))))
     (build-system gnu-build-system)
     (native-inputs
      (list pkg-config
-- 
2.34.0

0005-gnu-libmateweather-Update-to-1.26.0-and-use-G-expres.patch0000644000175000017460000000606314206265675022542 0ustar  fengusersFrom 13f171e1b069176c617fcff502ca043f2d7e151f Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:39:03 +0800
Subject: [PATCH 05/34] gnu: libmateweather: Update to 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (libmateweather): Update to 1.26.0.
[arguments]: Use G-expressions.
[native-inputs]: Remove labels.
---
 gnu/packages/mate.scm | 36 ++++++++++++++++++------------------
 1 file changed, 18 insertions(+), 18 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 790ef7fbb3..387e90183a 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -28,6 +28,7 @@ (define-module (gnu packages mate)
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix packages)
   #:use-module (guix download)
+  #:use-module (guix gexp)
   #:use-module (guix utils)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system glib-or-gtk)
@@ -252,36 +253,35 @@ (define-public mate-desktop
 (define-public libmateweather
   (package
     (name "libmateweather")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "libmateweather-" version ".tar.xz"))
        (sha256
-        (base32 "02d7c59pami1fzxg73mp6risa9hvsdpgs68f62wkg09nrppzsk4v"))))
+        (base32 "05bvc220p135l6qnhh3qskljxffds0f7fjbjnrpq524w149rgzd7"))))
     (build-system gnu-build-system)
     (arguments
-     '(#:configure-flags
-       (list (string-append "--with-zoneinfo-dir="
-                            (assoc-ref %build-inputs "tzdata")
-                            "/share/zoneinfo"))
-       #:phases
-       (modify-phases %standard-phases
-         (add-before 'check 'fix-tzdata-location
-          (lambda* (#:key inputs #:allow-other-keys)
-            (substitute* "data/check-timezones.sh"
-              (("/usr/share/zoneinfo/zone.tab")
-               (search-input-file inputs "/share/zoneinfo/zone.tab"))))))))
+     (list
+      #:configure-flags
+      #~(list (string-append "--with-zoneinfo-dir=" #$tzdata "/share/zoneinfo"))
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-before 'check 'fix-tzdata-location
+            (lambda* (#:key inputs #:allow-other-keys)
+              (substitute* "data/check-timezones.sh"
+                (("/usr/share/zoneinfo/zone.tab")
+                 (search-input-file inputs "/share/zoneinfo/zone.tab"))))))))
     (native-inputs
-     `(("pkg-config" ,pkg-config)
-       ("intltool" ,intltool)
-       ("dconf" ,dconf)
-       ("glib:bin" ,glib "bin")))
+     (list pkg-config
+           intltool
+           dconf
+           (list glib "bin")))
     (inputs
      (list gtk+ tzdata))
     (propagated-inputs
-      ;; both of these are requires.private in mateweather.pc
+     ;; both of these are requires.private in mateweather.pc
      (list libsoup-minimal-2 libxml2))
     (home-page "https://mate-desktop.org/")
     (synopsis "MATE library for weather information from the Internet")
-- 
2.34.0

0006-gnu-mate-terminal-Update-to-1.26.0.patch0000644000175000017460000000216014206265675017255 0ustar  fengusersFrom c0483f46e08784a39a26ef408d97fe9f0b2ab1d4 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:45:13 +0800
Subject: [PATCH 06/34] gnu: mate-terminal: Update to 1.26.0.

* gnu/packages/mate.scm (mate-terminal): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 387e90183a..0236d11b59 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -293,14 +293,14 @@ (define-public libmateweather
 (define-public mate-terminal
   (package
     (name "mate-terminal")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-terminal-" version ".tar.xz"))
        (sha256
-        (base32 "0qmyhxmarwkxad8k1m9q1iwx70zhfp6zc2mh74nv26nj4gr3h3am"))))
+        (base32 "08mgxbviik2dwwnbclp0518wlag2fhcr6c2yadgcbhwiq4aff9vp"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config
-- 
2.34.0

0007-gnu-mate-session-manager-Update-to-1.26.0-and-use-G-.patch0000644000175000017460000000540714206265675022340 0ustar  fengusersFrom f701046b824a5206a6f98a0c6499b2a7426aeeb2 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:52:22 +0800
Subject: [PATCH 07/34] gnu: mate-session-manager: Update to 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (mate-session-manager): Update to 1.26.0.
[arguments]: Use G-expressions.
---
 gnu/packages/mate.scm | 35 ++++++++++++++++-------------------
 1 file changed, 16 insertions(+), 19 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 0236d11b59..e1b92a11d2 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -332,33 +332,30 @@ (define-public mate-terminal
 (define-public mate-session-manager
   (package
     (name "mate-session-manager")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-session-manager-" version ".tar.xz"))
        (sha256
-        (base32 "1zwq8symyp3ijs28pyrknsdi9byf4dpp9wp93ndwdhi0vaip5i51"))))
+        (base32 "05hqi8wlwjr07mp5njhp7h06mgnv98zsxaxkmxc5w3iwb3va45ar"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags (list "--with-elogind"
-                               "--disable-schemas-compile")
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'install 'update-xsession-dot-desktop
-           (lambda* (#:key outputs #:allow-other-keys)
-             ;; Record the absolute file name of 'mate-session' in the
-             ;; '.desktop' file.
-             (let* ((out (assoc-ref outputs "out"))
-                    (xsession (string-append
-                               out "/share/xsessions/mate.desktop")))
-               (substitute* xsession
-                 (("^Exec=.*$")
-                  (string-append "Exec=" out "/bin/mate-session\n"))
-                 (("^TryExec=.*$")
-                  (string-append "Exec=" out "/bin/mate-session\n")))
-               #t))))))
+     (list
+      #:configure-flags
+      #~(list "--with-elogind" "--disable-schemas-compile")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'install 'update-xsession-dot-desktop
+            (lambda _
+              ;; Record the absolute file name of 'mate-session' in the
+              ;; '.desktop' file.
+              (substitute* (string-append #$output"/share/xsessions/mate.desktop")
+                (("^Exec=.*$")
+                 (string-append "Exec=" #$output "/bin/mate-session\n"))
+                (("^TryExec=.*$")
+                 (string-append "Exec=" #$output "/bin/mate-session\n"))))))))
     (native-inputs
      (list pkg-config intltool libxcomposite xtrans
            gobject-introspection))
-- 
2.34.0

0008-gnu-mate-settings-daemon-Update-to-1.26.0.patch0000644000175000017460000000227214206265675020551 0ustar  fengusersFrom 511660b84a07ade786034ef7162ab29eafb15526 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:56:26 +0800
Subject: [PATCH 08/34] gnu: mate-settings-daemon: Update to 1.26.0.

* gnu/packages/mate.scm (mate-settings-daemon): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index e1b92a11d2..50c3a0a358 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -371,14 +371,14 @@ (define-public mate-session-manager
 (define-public mate-settings-daemon
   (package
     (name "mate-settings-daemon")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-settings-daemon-" version ".tar.xz"))
        (sha256
-        (base32 "0n1ywr3ir5p536s7azdbw2mh40ylqlpx3a74mjrivbms1rpjxyab"))))
+        (base32 "0hbdwqagxh1mdpxfdqr1ps3yqvk0v0c5zm0bwk56y6l1zwbs0ymp"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config intltool gobject-introspection))
-- 
2.34.0

0009-gnu-libmatemixer-Update-to-1.26.0.patch0000644000175000017460000000222214206265675017202 0ustar  fengusersFrom c03252b1f2e23c43e28cbb51bfee378576938cdb Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 19:57:54 +0800
Subject: [PATCH 09/34] gnu: libmatemixer: Update to 1.26.0.

* gnu/packages/mate.scm (libmatemixer): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 50c3a0a358..1086430845 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -410,14 +410,14 @@ (define-public mate-settings-daemon
 (define-public libmatemixer
   (package
     (name "libmatemixer")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "libmatemixer-" version ".tar.xz"))
        (sha256
-        (base32 "1n6rq7k66zvfd6sb7h92xihh021w9hysfa4yd1mzjcbb7c62ybqx"))))
+        (base32 "1wcz4ppg696m31f5x7rkyvxxdriik2vprsr83b4wbs97bdhcr6ws"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config intltool gobject-introspection))
-- 
2.34.0

0010-gnu-libmatekbd-Update-1.26.0.patch0000644000175000017460000000217214206265675016172 0ustar  fengusersFrom ff93e1f66b77bc25e2e3ea2f4b4947188f271f20 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:00:08 +0800
Subject: [PATCH 10/34] gnu: libmatekbd: Update 1.26.0.

* gnu/packages/mate.scm (libmatekbd): Update 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 1086430845..544cedc0de 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -434,14 +434,14 @@ (define-public libmatemixer
 (define-public libmatekbd
   (package
     (name "libmatekbd")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "libmatekbd-" version ".tar.xz"))
        (sha256
-        (base32 "17mcxfkvl14p04id3n5kbhpjwjq00c8wmbyciyy2hm7kwdln6zx8"))))
+        (base32 "1b8iv2hmy8z2zzdsx8j5g583ddxh178bq8dnlqng9ifbn35fh3i2"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config intltool gobject-introspection))
-- 
2.34.0

0011-gnu-mate-menus-Update-to-1.26.0-and-use-G-expression.patch0000644000175000017460000000515714206265675022511 0ustar  fengusersFrom 9c966c488ade7a1e816bc3281cc0188c1cc8f67a Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:09:37 +0800
Subject: [PATCH 11/34] gnu: mate-menus: Update to 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (mate-menus): Update to 1.26.0.
[arguments]: Use G-expressions.
[inputs]: Remove labels.
---
 gnu/packages/mate.scm | 29 +++++++++++++----------------
 1 file changed, 13 insertions(+), 16 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 544cedc0de..18d4c3854c 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -462,33 +462,30 @@ (define-public libmatekbd
 (define-public mate-menus
   (package
     (name "mate-menus")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-menus-" version ".tar.xz"))
        (sha256
-        (base32 "17zc9fn14jykhn30z8iwlw0qwk32ivj6gxgww3xrqvqk0da5yaas"))))
+        (base32 "1r7zf64aclaplz77hkl9kq0xnz6jk1l49z64i8v56c41pm59c283"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-after
-          'unpack 'fix-introspection-install-dir
-          (lambda* (#:key outputs #:allow-other-keys)
-            (let ((out (assoc-ref outputs "out")))
-              (substitute* '("configure")
-                (("`\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0`")
-                 (string-append "\"" out "/share/gir-1.0/\""))
-                (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
-                 (string-append out "/lib/girepository-1.0/")))
-              #t))))))
+     (list #:phases
+           #~(modify-phases %standard-phases
+               (add-after
+                   'unpack 'fix-introspection-install-dir
+                 (lambda _
+                   (substitute* '("configure")
+                     (("`\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0`")
+                      (string-append "\"" #$output "/share/gir-1.0/\""))
+                     (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
+                      (string-append #$output "/lib/girepository-1.0/"))))))))
     (native-inputs
      (list pkg-config intltool gobject-introspection))
     (inputs
-     `(("glib" ,glib)
-       ("python" ,python-2)))
+     (list glib python-2))
     (home-page "https://mate-desktop.org/")
     (synopsis "Freedesktop menu specification implementation for MATE")
     (description
-- 
2.34.0

0012-gnu-mate-panel-Update-to-1.26.2-and-Use-G-expression.patch0000644000175000017460000000716014206265675022420 0ustar  fengusersFrom 03787c8f93ee44a75fba193ea2ad3389cec28438 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:23:29 +0800
Subject: [PATCH 12/34] gnu: mate-panel: Update to 1.26.2 and Use
 G-expressions.

* gnu/packages/mate.scm (mate-panel): Update to 1.26.2.
[arguments]: Use G-expressions.
---
 gnu/packages/mate.scm | 51 ++++++++++++++++++++-----------------------
 1 file changed, 24 insertions(+), 27 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 18d4c3854c..b46732a383 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -601,41 +601,38 @@ (define-public mate-media
 (define-public mate-panel
   (package
     (name "mate-panel")
-    (version "1.24.1")
+    (version "1.26.2")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            name "-" version ".tar.xz"))
        (sha256
-        (base32 "0xblqrhfazd01h0jdmx4hvavkb7f9anbd4rjsk5r6wxhp027l64l"))))
+        (base32 "042lw29y816hr0hhyrncvvs14afqy6109van0v67d7n5i66gki5f"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags
-       (list (string-append "--with-zoneinfo-dir="
-                            (assoc-ref %build-inputs "tzdata")
-                            "/share/zoneinfo")
-             "--with-in-process-applets=all")
-       #:phases
-       (modify-phases %standard-phases
-         (add-before 'configure 'fix-timezone-path
-           (lambda* (#:key inputs #:allow-other-keys)
-             (let* ((tzdata (assoc-ref inputs "tzdata")))
-               (substitute* "applets/clock/system-timezone.h"
-                 (("/usr/share/lib/zoneinfo/tab")
-                  (string-append tzdata "/share/zoneinfo/zone.tab"))
-                 (("/usr/share/zoneinfo")
-                  (string-append tzdata "/share/zoneinfo"))))
-             #t))
-         (add-after 'unpack 'fix-introspection-install-dir
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out")))
-               (substitute* '("configure")
-                 (("`\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0`")
-                  (string-append "\"" out "/share/gir-1.0/\""))
-                 (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
-                  (string-append out "/lib/girepository-1.0/")))
-               #t))))))
+     (list
+      #:configure-flags
+      #~(list (string-append "--with-zoneinfo-dir="
+                             #$tzdata
+                             "/share/zoneinfo")
+              "--with-in-process-applets=all")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-before 'configure 'fix-timezone-path
+            (lambda _
+              (substitute* "applets/clock/system-timezone.h"
+                (("/usr/share/lib/zoneinfo/tab")
+                 (string-append #$tzdata "/share/zoneinfo/zone.tab"))
+                (("/usr/share/zoneinfo")
+                 (string-append #$tzdata "/share/zoneinfo")))))
+          (add-after 'unpack 'fix-introspection-install-dir
+            (lambda _
+              (substitute* '("configure")
+                (("`\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0`")
+                 (string-append "\"" #$output "/share/gir-1.0/\""))
+                (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
+                 (string-append #$output "/lib/girepository-1.0/"))))))))
     (native-inputs
      (list pkg-config intltool itstool xtrans gobject-introspection))
     (inputs
-- 
2.34.0

0013-gnu-mate-applets-Update-to-1.26.0.patch0000644000175000017460000000246214206265675017115 0ustar  fengusersFrom c56f72a64b04cb63dec729134571305895697920 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:31:41 +0800
Subject: [PATCH 13/34] gnu: mate-applets: Update to 1.26.0.

* gnu/packages/mate.scm (mate-applets): Update to 1.26.0.
---
 gnu/packages/mate.scm | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index b46732a383..3832aeab14 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -497,14 +497,14 @@ (define-public mate-menus
 (define-public mate-applets
   (package
     (name "mate-applets")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-applets-" version ".tar.xz"))
        (sha256
-        (base32 "0h70i4x3bk017pgv4zn280682wm58vwdjm7kni91ni8rmblnnvyp"))))
+        (base32 "0xy9dwiqvmimqshbfq80jxq65aznlgx491lqq8rl4x8c9sdl7q5p"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config
@@ -525,6 +525,7 @@ (define-public mate-applets
            gtksourceview-3
            libgtop
            libmateweather
+           libnl
            libnotify
            libx11
            libxml2
-- 
2.34.0

0014-gnu-mate-media-Update-to-1.26.0.patch0000644000175000017460000000222014206265675016515 0ustar  fengusersFrom 463e0cb7392b2ff4c45f9e9c5d9f1589a9fb4818 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:34:09 +0800
Subject: [PATCH 14/34] gnu: mate-media: Update to 1.26.0.

* gnu/packages/mate.scm (mate-media): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 3832aeab14..3a98138511 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -570,14 +570,14 @@ (define-public mate-applets
 (define-public mate-media
   (package
     (name "mate-media")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-media-" version ".tar.xz"))
        (sha256
-        (base32 "118i4w2i2g3hfgbfn3hjzjkfq8vjj6049r7my3vna9js23b7ab92"))))
+        (base32 "0fiwzsir8i1bqz7g7b20g5zs28qq63j41v9c5z69q8fq7wh1nwwb"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config intltool gettext-minimal gobject-introspection))
-- 
2.34.0

0016-gnu-caja-extensions-Update-to-1.26.0-and-use-G-expre.patch0000644000175000017460000000621314206265675022454 0ustar  fengusersFrom 5d16d56a5062870bae11cf5e2e362994819a15d1 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:50:18 +0800
Subject: [PATCH 16/34] gnu: caja-extensions: Update to 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (caja-extensions): Update to 1.26.0.
[arguments]: Use G-expressions.
[native-inputs]: Remove labels.
---
 gnu/packages/mate.scm | 42 ++++++++++++++++++++++--------------------
 1 file changed, 22 insertions(+), 20 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index db095a977c..6249471cae 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -830,35 +830,37 @@ (define-public caja
 (define-public caja-extensions
   (package
     (name "caja-extensions")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "caja-extensions-" version ".tar.xz"))
        (sha256
-        (base32 "13jkynanqj8snys0if8lv6yx1y0jrm778s2152n4x65hsghc6cw5"))))
+        (base32 "03zwv3yl5553cnp6jjn7vr4l28dcdhsap7qimlrbvy20119kj5gh"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags (list "--enable-sendto"
-                               ;; TODO: package "gupnp" to enable 'upnp', package
-                               ;; "gksu" to enable 'gksu'.
-                               (string-append "--with-sendto-plugins=removable-devices,"
-                                              "caja-burn,emailclient,pidgin,gajim")
-                               "--enable-image-converter"
-                               "--enable-open-terminal" "--enable-share"
-                               "--enable-wallpaper" "--enable-xattr-tags"
-                               (string-append "--with-cajadir="
-                                              (assoc-ref %outputs "out")
-                                              "/lib/caja/extensions-2.0/"))))
+     (list #:configure-flags
+           #~(list "--enable-sendto"
+                   ;; TODO: package "gupnp" to enable 'upnp', package
+                   ;; "gksu" to enable 'gksu'.
+                   (string-append "--with-sendto-plugins=removable-devices,"
+                                  "caja-burn,emailclient,pidgin,gajim")
+                   "--enable-image-converter"
+                   "--enable-open-terminal"
+                   "--enable-share"
+                   "--enable-wallpaper"
+                   "--enable-xattr-tags"
+                   (string-append "--with-cajadir=" #$output
+                                  "/lib/caja/extensions-2.0/"))))
     (native-inputs
-     `(("intltool" ,intltool)
-       ("gettext" ,gettext-minimal)
-       ("glib:bin" ,glib "bin")
-       ("gobject-introspection" ,gobject-introspection)
-       ("gtk-doc" ,gtk-doc)
-       ("libxml2" ,libxml2)
-       ("pkg-config" ,pkg-config)))
+     (list intltool
+           gettext-minimal
+           (list glib "bin")
+           gobject-introspection
+           gtk-doc
+           libxml2
+           pkg-config))
     (inputs
      (list attr
            brasero
-- 
2.34.0

0017-gnu-mate-control-center-Update-1.26.0-and-use-G-expr.patch0000644000175000017460000001022414206265675022454 0ustar  fengusersFrom ee63e9d6e179baeb23375ff30737713336bbd308 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:59:33 +0800
Subject: [PATCH 17/34] gnu: mate-control-center: Update 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (mate-control-center): Update 1.26.0.
[arguments]: Use G-expressions.
[input]: Remove labels.
---
 gnu/packages/mate.scm | 83 +++++++++++++++++++++----------------------
 1 file changed, 41 insertions(+), 42 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 6249471cae..321833068c 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -885,28 +885,27 @@ (define-public caja-extensions
 (define-public mate-control-center
   (package
     (name "mate-control-center")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-control-center-" version ".tar.xz"))
        (sha256
-        (base32 "08bai47fsmbxlw2lhig9n6c8sxr24ixkd1spq3j0635yzcqighb0"))))
+        (base32 "0jhkn0vaz8glji4j5ar6im8l2wf40kssl07gfkz40rcgfzm18rr8"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     '(#:phases (modify-phases %standard-phases
-                  (add-before 'build 'fix-polkit-action
-                    (lambda* (#:key outputs #:allow-other-keys)
-                      ;; Make sure the polkit file refers to the right
-                      ;; executable.
-                      (let ((out (assoc-ref outputs "out")))
-                        (substitute*
-                            '("capplets/display/org.mate.randr.policy.in"
-                              "capplets/display/org.mate.randr.policy")
-                          (("/usr/sbin")
-                           (string-append out "/sbin")))
-                        #t))))))
+     (list #:phases
+           #~(modify-phases %standard-phases
+               (add-before 'build 'fix-polkit-action
+                 (lambda _
+                   ;; Make sure the polkit file refers to the right
+                   ;; executable.
+                   (substitute*
+                       '("capplets/display/org.mate.randr.policy.in"
+                         "capplets/display/org.mate.randr.policy")
+                     (("/usr/sbin")
+                      (string-append #$output "/sbin"))))))))
     (native-inputs
      (list pkg-config
            intltool
@@ -916,34 +915,34 @@ (define-public mate-control-center
            xmodmap
            gobject-introspection))
     (inputs
-     `(("atk" ,atk)
-       ("cairo" ,cairo)
-       ("caja" ,caja)
-       ("dconf" ,dconf)
-       ("dbus" ,dbus)
-       ("dbus-glib" ,dbus-glib)
-       ("fontconfig" ,fontconfig)
-       ("freetype" ,freetype)
-       ("glib" ,glib)
-       ("gtk+" ,gtk+)
-       ("libcanberra" ,libcanberra)
-       ("libmatekbd" ,libmatekbd)
-       ("libx11" ,libx11)
-       ("libxcursor" ,libxcursor)
-       ("libxext" ,libxext)
-       ("libxi" ,libxi)
-       ("libxklavier" ,libxklavier)
-       ("libxml2" ,libxml2)
-       ("libxrandr" ,libxrandr)
-       ("libxrender" ,libxrender)
-       ("libxscrnsaver" ,libxscrnsaver)
-       ("marco" ,marco)
-       ("mate-desktop" ,mate-desktop)
-       ("mate-menus" ,mate-menus)
-       ("mate-settings-daemon" ,mate-settings-daemon)
-       ("pango" ,pango)
-       ("polkit" ,polkit)
-       ("startup-notification" ,startup-notification)))
+     (list atk
+           cairo
+           caja
+           dconf
+           dbus
+           dbus-glib
+           fontconfig
+           freetype
+           glib
+           gtk+
+           libcanberra
+           libmatekbd
+           libx11
+           libxcursor
+           libxext
+           libxi
+           libxklavier
+           libxml2
+           libxrandr
+           libxrender
+           libxscrnsaver
+           marco
+           mate-desktop
+           mate-menus
+           mate-settings-daemon
+           pango
+           polkit
+           startup-notification))
     (propagated-inputs
      (list (librsvg-for-system)))        ;mate-slab.pc
     (home-page "https://mate-desktop.org/")
-- 
2.34.0

0018-gnu-marco-Update-1.26.0.patch0000644000175000017460000000210714206265675015203 0ustar  fengusersFrom 0120975d3d3280b75fb8d897c02fa4c22cd276b7 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 21:01:44 +0800
Subject: [PATCH 18/34] gnu: marco: Update 1.26.0.

* gnu/packages/mate.scm (marco): Update 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 321833068c..fcc186cd14 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -955,14 +955,14 @@ (define-public mate-control-center
 (define-public marco
   (package
     (name "marco")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            name "-" version ".tar.xz"))
        (sha256
-        (base32 "109b41pjrc1b4slw6sx1lakdhrc46x829vczzk4bz3j15kcszg54"))))
+        (base32 "01avxrg2fc6grfrp6hl8b0im4scy9xf6011swfrhli87ig6hhg7n"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list pkg-config
-- 
2.34.0

0019-gnu-mate-user-guide-Update-to-1.26.0-and-use-G-expre.patch0000644000175000017460000000433514206265675022364 0ustar  fengusersFrom 048d695bfda728450ed830825f819c72c0a9954c Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 21:16:21 +0800
Subject: [PATCH 19/34] gnu: mate-user-guide: Update to 1.26.0 and use
 G-expressions.

* gnu/packages/mate.scm (mate-user-guide): Update to 1.26.0.
[arguments]: Use G-expressions.
[native-inputs]: Remove labels.
---
 gnu/packages/mate.scm | 30 ++++++++++++++----------------
 1 file changed, 14 insertions(+), 16 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index fcc186cd14..311debc5da 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1004,7 +1004,7 @@ (define-public marco
 (define-public mate-user-guide
   (package
     (name "mate-user-guide")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -1012,24 +1012,22 @@ (define-public mate-user-guide
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "0ddxya84iydvy85dbqls0wmz2rph87wri3rsdhv4rkbhh5g4sd7f"))))
+         "1h620ngryqc4m8ybvc92ba8404djnm0l65f34mlw38g9ad8d9085"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'adjust-desktop-file
-           (lambda* (#:key inputs #:allow-other-keys)
-             (let* ((yelp (assoc-ref inputs "yelp")))
-               (substitute* "mate-user-guide.desktop.in.in"
-                 (("yelp")
-                  (string-append yelp "/bin/yelp"))))
-             #t)))))
+     (list #:phases
+           #~(modify-phases %standard-phases
+               (add-after 'unpack 'adjust-desktop-file
+                 (lambda _
+                   (substitute* "mate-user-guide.desktop.in.in"
+                     (("yelp")
+                      (string-append #$yelp "/bin/yelp"))))))))
     (native-inputs
-     `(("pkg-config" ,pkg-config)
-       ("intltool" ,intltool)
-       ("gettext" ,gettext-minimal)
-       ("yelp-tools" ,yelp-tools)
-       ("yelp-xsl" ,yelp-xsl)))
+     (list pkg-config
+           intltool
+           gettext-minimal
+           yelp-tools
+           yelp-xsl))
     (inputs
      (list yelp))
     (home-page "https://mate-desktop.org/")
-- 
2.34.0

0020-gnu-mate-calc-Update-to-1.26.0.patch0000644000175000017460000000337714206265675016353 0ustar  fengusersFrom 8f04018d64b346bdd59febdaee3dbd8794789c5b Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:25:14 +0800
Subject: [PATCH 20/34] gnu: mate-calc: Update to 1.26.0.

* gnu/packages/mate.scm (mate-calc): Update to 1.26.0.
[inputs]: Add mpc and mpfr.
(gnu): Use multiprecision.
---
 gnu/packages/mate.scm | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 311debc5da..4c0a1e55fe 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -60,6 +60,7 @@ (define-module (gnu packages mate)
   #:use-module (gnu packages libcanberra)
   #:use-module (gnu packages linux)
   #:use-module (gnu packages messaging)
+  #:use-module (gnu packages multiprecision)
   #:use-module (gnu packages nss)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages pdf)
@@ -1041,14 +1042,14 @@ (define-public mate-user-guide
 (define-public mate-calc
   (package
     (name "mate-calc")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-calc-" version ".tar.xz"))
        (sha256
-        (base32 "0imdimq5d5rjq8mkjcrsd683a2bn9acmhc0lmvyw71y0040inbaw"))))
+        (base32 "0mddfh9ixhh60nfgx5kcprcl9liavwqyina11q3pnpfs3n02df3y"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list gettext-minimal intltool pkg-config yelp-tools))
@@ -1058,6 +1059,8 @@ (define-public mate-calc
            gtk+
            libxml2
            libcanberra
+           mpc
+           mpfr
            pango))
     (home-page "https://mate-desktop.org/")
     (synopsis "Calculator for MATE")
-- 
2.34.0

0021-gnu-mate-backgrounds-Update-to-1.26.0.patch0000644000175000017460000000213114206265675017737 0ustar  fengusersFrom 0897fd09e012b492c892b8b4dcb1a4289ea7bdd4 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:27:06 +0800
Subject: [PATCH 21/34] gnu: mate-backgrounds: Update to 1.26.0.

* gnu/packages/mate.scm (mate-backgrounds): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 4c0a1e55fe..b007e574f3 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1071,7 +1071,7 @@ (define-public mate-calc
 (define-public mate-backgrounds
   (package
     (name "mate-backgrounds")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -1079,7 +1079,7 @@ (define-public mate-backgrounds
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "0b9yx68p9l867bqsl9z2g4wrs8p396ls673jgaliys5snmk8n8dn"))))
+         "0379hngy3ap1r5kmqvmzs9r710k2c9nal2ps3hq765df4ir15j8d"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list intltool))
-- 
2.34.0

0022-gnu-mate-netbook-Update-to-1.26.0.patch0000644000175000017460000000214714206265675017106 0ustar  fengusersFrom f96ceca5dc8f679f13b85f1080eb63e5ade9a942 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:28:54 +0800
Subject: [PATCH 22/34] gnu: mate-netbook: Update to 1.26.0.

* gnu/packages/mate.scm (mate-netbook): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index b007e574f3..9bb4163e4e 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1093,7 +1093,7 @@ (define-public mate-backgrounds
 (define-public mate-netbook
   (package
     (name "mate-netbook")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -1101,7 +1101,7 @@ (define-public mate-netbook
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "1bmk9gq5gcqkvfppa7i1hqfph8sajc3xs189s4ha97g0ifwd98a8"))))
+         "12gdy69nfysl8vmd8lv8b0lknkaagplrrz88nh6n0rmjkxnipgz3"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list gettext-minimal intltool pkg-config))
-- 
2.34.0

0023-gnu-mate-screensaver-Update-to-1.26.1-and-use-G-expr.patch0000644000175000017460000000633714206265675022466 0ustar  fengusersFrom d6d4b9e4805fa3bf10de2ea4dcad538939f9e27f Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:39:50 +0800
Subject: [PATCH 23/34] gnu: mate-screensaver: Update to 1.26.1 and use
 G-expressions.

* gnu/packages/mate.scm (mate-screensaver): Update to 1.26.1.
[arguments]: Use G-expressions.
[native-inputs]: Remove labels.
---
 gnu/packages/mate.scm | 53 +++++++++++++++++++++----------------------
 1 file changed, 26 insertions(+), 27 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 9bb4163e4e..8516484319 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1132,42 +1132,41 @@ (define-public mate-netbook
 (define-public mate-screensaver
   (package
     (name "mate-screensaver")
-    (version "1.24.1")
+    (version "1.26.1")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-screensaver-" version ".tar.xz"))
        (sha256
-        (base32 "0imb1z2yvz1h95dzq396c569kkxys9mb2dyc6qxxxcnc5w02a2dw"))))
+        (base32 "1g5qb6bf08726166c12n554kwxb9v1vgg6za6ggai7m5lhgb5gag"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags
-       ;; FIXME: There is a permissions problem with screen locking
-       ;; which effectively locks you out completely. Enable locking
-       ;; once this has been fixed.
-       (list "--enable-locking" "--with-kbd-layout-indicator"
-             "--with-xf86gamma-ext" "--enable-pam"
-             "--disable-schemas-compile" "--without-console-kit")
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'autoconf
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let* ((out (assoc-ref outputs "out"))
-                    (dbus-dir (string-append out "/share/dbus-1/services")))
-             (setenv "SHELL" (which "sh"))
-             (setenv "CONFIG_SHELL" (which "sh"))
-             (substitute* "configure"
-               (("dbus-1") ""))))))))
+     (list
+      #:configure-flags
+      ;; FIXME: There is a permissions problem with screen locking
+      ;; which effectively locks you out completely. Enable locking
+      ;; once this has been fixed.
+      #~(list "--enable-locking" "--with-kbd-layout-indicator"
+              "--with-xf86gamma-ext" "--enable-pam"
+              "--disable-schemas-compile" "--without-console-kit")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'autoconf
+            (lambda _
+              (setenv "SHELL" (which "sh"))
+              (setenv "CONFIG_SHELL" (which "sh"))
+              (substitute* "configure"
+                (("dbus-1") "")))))))
     (native-inputs
-     `(("automake" ,automake)
-       ("autoconf" ,autoconf)
-       ("gettext" ,gettext-minimal)
-       ("intltool" ,intltool)
-       ("mate-common" ,mate-common)
-       ("pkg-config" ,pkg-config)
-       ("which" ,which)
-       ("xorgproto" ,xorgproto)))
+     (list automake
+           autoconf
+           gettext-minimal
+           intltool
+           mate-common
+           pkg-config
+           which
+           xorgproto))
     (inputs
      (list cairo
            dconf
-- 
2.34.0

0024-gnu-mates-utils-Update-to-1.26.0.patch0000644000175000017460000000211014206265675016760 0ustar  fengusersFrom 229d4a2b12a413512a8c19026a4ed9a93c263fb3 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:44:18 +0800
Subject: [PATCH 24/34] gnu: mates-utils: Update to 1.26.0.

* gnu/packages/mate.scm (mate-utils): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 8516484319..674d7828a9 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1201,7 +1201,7 @@ (define-public mate-screensaver
 (define-public mate-utils
   (package
     (name "mate-utils")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -1209,7 +1209,7 @@ (define-public mate-utils
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "1b16n1628gcsym5mph6lr9x5xm4rgkxsa8xwr2wlx8g2gw2775i1"))))
+         "0bkqj8qwwml9xyvb680yy06lv3dzwkv89yrzz5jamvz88ar6m9bw"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list gettext-minimal
-- 
2.34.0

0025-gnu-eom-Update-to-1.26.0.patch0000644000175000017460000000210114206265675015272 0ustar  fengusersFrom f45eb82df809b60f7a9ed2fcdaafa900063fdbae Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:46:18 +0800
Subject: [PATCH 25/34] gnu: eom: Update to 1.26.0.

* gnu/packages/mate.scm (eom): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 674d7828a9..cf8d0636a0 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1254,14 +1254,14 @@ (define-public mate-utils
 (define-public eom
   (package
     (name "eom")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "eom-" version ".tar.xz"))
        (sha256
-        (base32 "0dralsc0dvs0l38cysdhx6kiaiqlb8qi6g9xz2cm6mjqyq3d3f9f"))))
+        (base32 "1nv7q0yw11grgxr5lyvll0f7fl823kpjp05z81bwgnvd76m6kw97"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list gettext-minimal
-- 
2.34.0

0026-gnu-engrampa-Update-1.26.0-and-use-G-expressions.patch0000644000175000017460000000564314206265675022001 0ustar  fengusersFrom 54f50179dc7201f29c88747faba62064685e4d57 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:50:58 +0800
Subject: [PATCH 26/34] gnu: engrampa: Update 1.26.0 and use G-expressions.

* gnu/packages/mate.scm (engrampa): Update 1.26.0.
[arguments]: Use G-expressions.
[native-inputs]: Remove labels.
---
 gnu/packages/mate.scm | 44 +++++++++++++++++++++----------------------
 1 file changed, 22 insertions(+), 22 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index cf8d0636a0..cb57106c67 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1302,37 +1302,37 @@ (define-public eom
 (define-public engrampa
   (package
     (name "engrampa")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "engrampa-" version ".tar.xz"))
        (sha256
-        (base32 "0akjnz85qkpiqgj1ccn41rzbfid4l3r3nsm4s9s779ilzd7f097y"))))
+        (base32 "1qsy0ynhj1v0kyn3g3yf62g31rwxmpglfh9xh0w5lc9j5k1b5kcp"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags (list "--disable-schemas-compile"
-                               "--disable-run-in-place"
-                               "--enable-magic"
-                               "--enable-packagekit"
-                               (string-append "--with-cajadir="
-                                              (assoc-ref %outputs "out")
-                                              "/lib/caja/extensions-2.0/"))
-       #:phases
-       (modify-phases %standard-phases
-         (add-before 'install 'skip-gtk-update-icon-cache
-           ;; Don't create 'icon-theme.cache'.
-           (lambda _
-             (substitute* "data/Makefile"
-               (("gtk-update-icon-cache") "true"))
-             #t)))))
+     (list #:configure-flags
+           #~(list "--disable-schemas-compile"
+                   "--disable-run-in-place"
+                   "--enable-magic"
+                   "--enable-packagekit"
+                   (string-append "--with-cajadir="
+                                  #$output
+                                  "/lib/caja/extensions-2.0/"))
+           #:phases
+           #~(modify-phases %standard-phases
+               (add-before 'install 'skip-gtk-update-icon-cache
+                 ;; Don't create 'icon-theme.cache'.
+                 (lambda _
+                   (substitute* "data/Makefile"
+                     (("gtk-update-icon-cache") "true")))))))
     (native-inputs
-     `(("gettext" ,gettext-minimal)
-       ("gtk-doc" ,gtk-doc)
-       ("intltool" ,intltool)
-       ("pkg-config" ,pkg-config)
-       ("yelp-tools" ,yelp-tools)))
+     (list gettext-minimal
+           gtk-doc
+           intltool
+           pkg-config
+           yelp-tools))
     (inputs
      (list caja
            file
-- 
2.34.0

0027-gnu-pluma-Update-1.26.0-and-Remove-labels.patch0000644000175000017460000000367714206265675020470 0ustar  fengusersFrom 32b0eab5fb45359c3a864c794d265b151ac262f9 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:56:09 +0800
Subject: [PATCH 27/34] gnu: pluma: Update 1.26.0 and Remove labels.

* gnu/packages/mate.scm (pluma): Update 1.26.0.
[native-inputs]: Remove labels.
[inputs]: Use gtksourceview instead of gtksourceview-3.
---
 gnu/packages/mate.scm | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index cb57106c67..92d64bb1aa 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1354,34 +1354,34 @@ (define-public engrampa
 (define-public pluma
   (package
     (name "pluma")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            name "-" version ".tar.xz"))
        (sha256
-        (base32 "1sgc5f480icr2ans6gd3akvcax58mr4jp3zjk3xn7bx1mw9i299f"))))
+        (base32 "0lway12q2xygiwjgrx7chgka838jbnmlzz98g7agag1rwzd481ii"))))
     (build-system glib-or-gtk-build-system)
     (arguments
      `(; Tests can not succeed.
        ;; https://github.com/mate-desktop/mate-text-editor/issues/33
        #:tests? #f))
     (native-inputs
-     `(("gettext" ,gettext-minimal)
-       ("gtk-doc" ,gtk-doc)
-       ("gobject-introspection" ,gobject-introspection)
-       ("intltool" ,intltool)
-       ("libtool" ,libtool)
-       ("pkg-config" ,pkg-config)
-       ("yelp-tools" ,yelp-tools)))
+     (list gettext-minimal
+           gtk-doc
+           gobject-introspection
+           intltool
+           libtool
+           pkg-config
+           yelp-tools))
     (inputs
      (list atk
            cairo
            enchant-1.6
            glib
            gtk+
-           gtksourceview-3
+           gtksourceview
            gdk-pixbuf
            iso-codes
            libcanberra
-- 
2.34.0

0028-gnu-mate-system-monitor-Update-to-1.26.0.patch0000644000175000017460000000226614206265675020466 0ustar  fengusersFrom 084976add69e581c1d6dc8a64c0b141b24c20feb Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 04:59:27 +0800
Subject: [PATCH 28/34] gnu: mate-system-monitor: Update to 1.26.0.

* gnu/packages/mate.scm (mate-system-monitor): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 92d64bb1aa..b50ec85ffe 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1403,14 +1403,14 @@ (define-public pluma
 (define-public mate-system-monitor
   (package
     (name "mate-system-monitor")
-    (version "1.24.1")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/" (version-major+minor version) "/"
                            "mate-system-monitor-" version ".tar.xz"))
        (sha256
-        (base32 "1i2r4lw6xsk972yp15g5hm8p8xx9pp6jmcvvzbdq80xyx3x898qz"))))
+        (base32 "13rkrk7c326ng8164aqfp6i7334n7zrmbg61ncpjprbrvlx2qiw3"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list autoconf gettext-minimal intltool pkg-config yelp-tools))
-- 
2.34.0

0029-gnu-mate-polkit-Update-to-1.26.0.patch0000644000175000017460000000216514206265675016756 0ustar  fengusersFrom e515625bc96ce9941f25f7df1e5c8decdd38cf59 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 05:01:27 +0800
Subject: [PATCH 29/34] gnu: mate-polkit: Update to 1.26.0.

* gnu/packages/mate.scm (mate-polkit): Update to 1.26.0.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index b50ec85ffe..38cbd8f462 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1438,7 +1438,7 @@ (define-public mate-system-monitor
 (define-public mate-polkit
   (package
     (name "mate-polkit")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -1446,7 +1446,7 @@ (define-public mate-polkit
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "1450bqzlnvwy3xa98lj102j2cf7piqbxcd1cy2zp41rdl8ri3gvn"))))
+         "0kkjv025l1l8352m5ky1g7hmk7isgi3dnfnh7sqg9pyhml97i9dd"))))
     (build-system glib-or-gtk-build-system)
     (native-inputs
      (list gettext-minimal gtk-doc intltool libtool pkg-config))
-- 
2.34.0

0030-gnu-artil-Update-to-1.26.0-and-Use-G-expressions.patch0000644000175000017460000001560614206265675021675 0ustar  fengusersFrom ff66b1d130828430bcfa004b078759f842399fa4 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 05:13:43 +0800
Subject: [PATCH 30/34] gnu: artil: Update to 1.26.0 and Use G-expressions.

* gnu/packages/mate.scm (atril): Update to 1.26.0.
[arguments]: Use G-expressions.
[native-inputs, inputs]: Remove labels.
---
 gnu/packages/mate.scm | 160 ++++++++++++++++++++----------------------
 1 file changed, 77 insertions(+), 83 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 38cbd8f462..1d06982808 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -670,7 +670,7 @@ (define-public mate-panel
 (define-public atril
   (package
     (name "atril")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -678,92 +678,86 @@ (define-public atril
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "0967gxw7h2qh2kpwl0jgv58hicz6aa92kr12mnykbpikad25s95y"))))
+         "0pz44k3axhjhhwfrfvnwvxak1dmjkwqs63rhrbcaagyymrp7cpki"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags (list (string-append "--with-openjpeg="
-                                              (assoc-ref %build-inputs "openjpeg"))
-                               "--enable-introspection"
-                               "--disable-schemas-compile"
-                               ;; FIXME: Enable build of Caja extensions.
-                               "--disable-caja")
-       #:tests? #f
-       #:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'fix-mathjax-path
-           (lambda _
-             (let* ((mathjax (assoc-ref %build-inputs "js-mathjax"))
-                    (mathjax-path (string-append mathjax
-                                                 "/share/javascript/mathjax")))
-               (substitute* "backend/epub/epub-document.c"
-                 (("/usr/share/javascript/mathjax")
-                  mathjax-path)))
-             #t))
-         (add-after 'unpack 'fix-introspection-install-dir
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let ((out (assoc-ref outputs "out")))
-               (substitute* '("configure")
-                 (("\\$\\(\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0\\)")
-                  (string-append "\"" out "/share/gir-1.0/\""))
-                 (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
-                  (string-append out "/lib/girepository-1.0/")))
-               #t)))
-         (add-before 'install 'skip-gtk-update-icon-cache
-           ;; Don't create 'icon-theme.cache'.
-           (lambda _
-             (substitute* "data/Makefile"
-               (("gtk-update-icon-cache") "true"))
-             #t)))))
+     (list
+      #:configure-flags
+      #~(list (string-append "--with-openjpeg=" #$openjpeg "openjpeg")
+              "--enable-introspection"
+              "--disable-schemas-compile"
+              ;; FIXME: Enable build of Caja extensions.
+              "--disable-caja")
+      #:tests? #f
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'fix-mathjax-path
+            (lambda _
+              (substitute* "backend/epub/epub-document.c"
+                (("/usr/share/javascript/mathjax")
+                 (string-append #$js-mathjax "/share/javascript/mathjax")))))
+          (add-after 'unpack 'fix-introspection-install-dir
+            (lambda _
+              (substitute* '("configure")
+                (("\\$\\(\\$PKG_CONFIG --variable=girdir gobject-introspection-1.0\\)")
+                 (string-append "\"" #$output "/share/gir-1.0/\""))
+                (("\\$\\(\\$PKG_CONFIG --variable=typelibdir gobject-introspection-1.0\\)")
+                 (string-append #$output "/lib/girepository-1.0/")))))
+          (add-before 'install 'skip-gtk-update-icon-cache
+            ;; Don't create 'icon-theme.cache'.
+            (lambda _
+              (substitute* "data/Makefile"
+                (("gtk-update-icon-cache") "true")))))))
     (native-inputs
-     `(("pkg-config" ,pkg-config)
-       ("intltool" ,intltool)
-       ("itstool" ,itstool)
-       ("yelp-tools" ,yelp-tools)
-       ("glib:bin" ,glib "bin")
-       ("gobject-introspection" ,gobject-introspection)
-       ("gtk-doc" ,gtk-doc)
-       ("texlive-bin" ,texlive-bin) ;synctex
-       ("xmllint" ,libxml2)
-       ("zlib" ,zlib)))
+     (list pkg-config
+           intltool
+           itstool
+           yelp-tools
+           (list glib "bin")
+           gobject-introspection
+           gtk-doc
+           texlive-bin ;synctex
+           libxml2
+           zlib))
     (inputs
-     `(("atk" ,atk)
-       ("cairo" ,cairo)
-       ("caja" ,caja)
-       ("dconf" ,dconf)
-       ("dbus" ,dbus)
-       ("dbus-glib" ,dbus-glib)
-       ("djvulibre" ,djvulibre)
-       ("fontconfig" ,fontconfig)
-       ("freetype" ,freetype)
-       ("ghostscript" ,ghostscript)
-       ("glib" ,glib)
-       ("gtk+" ,gtk+)
-       ("js-mathjax" ,js-mathjax)
-       ("libcanberra" ,libcanberra)
-       ("libsecret" ,libsecret)
-       ("libspectre" ,libspectre)
-       ("libtiff" ,libtiff)
-       ("libx11" ,libx11)
-       ("libice" ,libice)
-       ("libsm" ,libsm)
-       ("libgxps" ,libgxps)
-       ("libjpeg" ,libjpeg-turbo)
-       ("libxml2" ,libxml2)
-       ("dogtail" ,python-dogtail)
-       ("shared-mime-info" ,shared-mime-info)
-       ("gdk-pixbuf" ,gdk-pixbuf)
-       ("gsettings-desktop-schemas" ,gsettings-desktop-schemas)
-       ("libgnome-keyring" ,libgnome-keyring)
-       ("libarchive" ,libarchive)
-       ("marco" ,marco)
-       ("openjpeg" ,openjpeg)
-       ("pango" ,pango)
-       ;;("texlive" ,texlive)
-       ;; TODO:
-       ;;   Build libkpathsea as a shared library for DVI support.
-       ;; ("libkpathsea" ,texlive-bin)
-       ("poppler" ,poppler)
-       ("webkitgtk" ,webkitgtk)))
+     (list atk
+           cairo
+           caja
+           dconf
+           dbus
+           dbus-glib
+           djvulibre
+           fontconfig
+           freetype
+           ghostscript
+           glib
+           gtk+
+           js-mathjax
+           libcanberra
+           libsecret
+           libspectre
+           libtiff
+           libx11
+           libice
+           libsm
+           libgxps
+           libjpeg-turbo
+           libxml2
+           python-dogtail
+           shared-mime-info
+           gdk-pixbuf
+           gsettings-desktop-schemas
+           libgnome-keyring
+           libarchive
+           marco
+           openjpeg
+           pango
+           ;; texlive
+           ;; TODO:
+           ;;   Build libkpathsea as a shared library for DVI support.
+           ;; ("libkpathsea" ,texlive-bin)
+           poppler
+           webkitgtk))
     (home-page "https://mate-desktop.org")
     (synopsis "Document viewer for Mate")
     (description
-- 
2.34.0

0031-gnu-mate-Update-to-1.26.0.patch0000644000175000017460000001125514206265675015447 0ustar  fengusersFrom d66159b5a9e107c75f2cbc86ad658d07073de9f1 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 05:30:09 +0800
Subject: [PATCH 31/34] gnu: mate: Update to 1.26.0.

* gnu/packages/mate.scm (mate): Update to 1.26.0.
[builder, inputs]: Use G-expression.
---
 gnu/packages/mate.scm | 103 +++++++++++++++++++++---------------------
 1 file changed, 51 insertions(+), 52 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 1d06982808..8179e91b56 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -1465,61 +1465,60 @@ (define-public mate
     (source #f)
     (build-system trivial-build-system)
     (arguments
-     `(#:modules ((guix build union))
-       #:builder
-       (begin
-         (use-modules (ice-9 match)
-                      (guix build union))
-         (match %build-inputs
-           (((names . directories) ...)
-            (union-build (assoc-ref %outputs "out")
-                         directories)
-            #t)))))
+     (list #:modules '((guix build union))
+           #:builder
+           #~(begin
+               (use-modules (ice-9 match)
+                            (guix build union))
+               (match %build-inputs
+                 (((names . directories) ...)
+                  (union-build #$output directories)
+                  #t)))))
     (native-inputs (list desktop-file-utils))
     (inputs
      ;; TODO: Add more packages
-     `(("at-spi2-core"              ,at-spi2-core)
-       ("atril"                     ,atril)
-       ("caja"                      ,caja)
-       ("dbus"                      ,dbus)
-       ("dconf"                     ,dconf)
-       ("engrampa"                  ,engrampa)
-       ("eom"                       ,eom)
-       ("font-abattis-cantarell"            ,font-abattis-cantarell)
-       ("glib-networking"           ,glib-networking)
-       ("gnome-keyring"             ,gnome-keyring)
-       ("gvfs"                      ,gvfs)
-       ("hicolor-icon-theme"        ,hicolor-icon-theme)
-       ("libmatekbd"                ,libmatekbd)
-       ("libmateweather"            ,libmateweather)
-       ("libmatemixer"              ,libmatemixer)
-       ("marco"                     ,marco)
-       ("mate-session-manager"      ,mate-session-manager)
-       ("mate-settings-daemon"      ,mate-settings-daemon)
-       ("mate-desktop"              ,mate-desktop)
-       ("mate-terminal"             ,mate-terminal)
-       ("mate-themes"               ,mate-themes)
-       ("mate-icon-theme"           ,mate-icon-theme)
-       ("mate-power-manager"        ,mate-power-manager)
-       ("mate-menu"                 ,mate-menus)
-       ("mate-panel"                ,mate-panel)
-       ("mate-control-center"       ,mate-control-center)
-       ("mate-media"                ,mate-media)
-       ("mate-applets"              ,mate-applets)
-       ("mate-user-guide"           ,mate-user-guide)
-       ("mate-calc"                 ,mate-calc)
-       ("mate-backgrounds"          ,mate-backgrounds)
-       ("mate-netbook"              ,mate-netbook)
-       ("mate-utils"                ,mate-utils)
-       ("mate-polkit"               ,mate-polkit)
-       ("mate-system-monitor"       ,mate-system-monitor)
-       ("mate-utils"                ,mate-utils)
-       ("pluma"                     ,pluma)
-       ("pinentry-gnome3"           ,pinentry-gnome3)
-       ("pulseaudio"                ,pulseaudio)
-       ("shared-mime-info"          ,shared-mime-info)
-       ("yelp"                      ,yelp)
-       ("zenity"                    ,zenity)))
+     (list at-spi2-core
+           atril
+           caja
+           dbus
+           dconf
+           engrampa
+           eom
+           font-abattis-cantarell
+           glib-networking
+           gnome-keyring
+           gvfs
+           hicolor-icon-theme
+           libmatekbd
+           libmateweather
+           libmatemixer
+           marco
+           mate-session-manager
+           mate-settings-daemon
+           mate-desktop
+           mate-terminal
+           mate-themes
+           mate-icon-theme
+           mate-power-manager
+           mate-menus
+           mate-panel
+           mate-control-center
+           mate-media
+           mate-applets
+           mate-user-guide
+           mate-calc
+           mate-backgrounds
+           mate-netbook
+           mate-utils
+           mate-polkit
+           mate-system-monitor
+           mate-utils
+           pluma
+           pinentry-gnome3
+           pulseaudio
+           shared-mime-info
+           yelp
+           zenity))
     (propagated-inputs
      ;; Default font that applications such as IceCat require.
      (list font-dejavu))
-- 
2.34.0

0032-gnu-mate-themes-Update-to-3.22.23.patch0000644000175000017460000000224014206265675017010 0ustar  fengusersFrom 95648d8cc1af4b2d277300d6e5c06d264918b839 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 05:37:29 +0800
Subject: [PATCH 32/34] gnu: mate-themes: Update to 3.22.23.

* gnu/packages/mate.scm (mate-themes): Update to 3.22.23.
---
 gnu/packages/mate.scm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 8179e91b56..1de52d4160 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -199,14 +199,14 @@ (define-public mate-icon-theme-faenza
 (define-public mate-themes
   (package
     (name "mate-themes")
-    (version "3.22.21")
+    (version "3.22.23")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "mirror://mate/themes/" (version-major+minor version)
                            "/mate-themes-" version ".tar.xz"))
        (sha256
-        (base32 "051g2vq817g84yrqzf7hjcqr4xrghnw1rprjd6jf5mhhzmwcas6n"))))
+        (base32 "1avgzccdmr7y18rnp3xrhwk82alv2dlig3wh7ivgahcqdiiavrb1"))))
     (build-system gnu-build-system)
     (native-inputs
      (list pkg-config intltool gdk-pixbuf ; gdk-pixbuf+svg isn't needed
-- 
2.34.0

0033-gnu-mate-icon-theme-faenza-Use-G-expressions.patch0000644000175000017460000000377214206265675021662 0ustar  fengusersFrom 29b67fc5c6c4bf049086784426f3700e391af409 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 05:46:10 +0800
Subject: [PATCH 33/34] gnu: mate-icon-theme-faenza: Use G-expressions.

* gnu/packages/mate.scm (mate-icon-theme-faenza) [arguments]: Use G-expressions.
[native-inputs]: Remove label.
---
 gnu/packages/mate.scm | 30 +++++++++++++++---------------
 1 file changed, 15 insertions(+), 15 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 1de52d4160..0a689352de 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -170,24 +170,24 @@ (define-public mate-icon-theme-faenza
          "000vr9cnbl2qlysf2gyg1lsjirqdzmwrnh6d3hyrsfc0r2vh4wna"))))
     (build-system gnu-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'autoconf
-           (lambda _
-             (setenv "SHELL" (which "sh"))
-             (setenv "CONFIG_SHELL" (which "sh"))
-             (invoke "sh" "autogen.sh"))))))
+     (list #:phases
+           #~(modify-phases %standard-phases
+               (add-after 'unpack 'autoconf
+                 (lambda _
+                   (setenv "SHELL" (which "sh"))
+                   (setenv "CONFIG_SHELL" (which "sh"))
+                   (invoke "sh" "autogen.sh"))))))
     (native-inputs
      ;; autoconf-wrapper is required due to the non-standard
      ;; 'autoconf phase.
-     `(("autoconf" ,autoconf-wrapper)
-       ("automake" ,automake)
-       ("intltool" ,intltool)
-       ("icon-naming-utils" ,icon-naming-utils)
-       ("libtool" ,libtool)
-       ("mate-common" ,mate-common)
-       ("pkg-config" ,pkg-config)
-       ("which" ,which)))
+     (list autoconf-wrapper
+           automake
+           intltool
+           icon-naming-utils
+           libtool
+           mate-common
+           pkg-config
+           which))
     (home-page "https://mate-desktop.org/")
     (synopsis "MATE desktop environment icon theme faenza")
     (description
-- 
2.34.0

0034-gnu-caja-Add-FIXME-about-CAJA_EXTENSION_DIRS.patch0000644000175000017460000000162614206265675020456 0ustar  fengusersFrom ad3a73e65041950ceefb5eb33b8e60b6e483444f Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Sat, 26 Feb 2022 07:44:28 +0800
Subject: [PATCH 34/34] gnu: caja: Add FIXME about $CAJA_EXTENSION_DIRS.

* gnu/packages/mate.scm (caja): Add FIXME about $CAJA_EXTENSION_DIRS.
---
 gnu/packages/mate.scm | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 0a689352de..0de3315c47 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -807,6 +807,8 @@ (define-public caja
            mate-desktop
            startup-notification))
     (native-search-paths
+     ;; FIXME: caja > 1.24 support $CAJA_EXTENSION_DIRS, it is a list of
+     ;; directories where caja extensions are looked for.
      (list (search-path-specification
             (variable "CAJA_EXTENSIONDIR")
             (files (list "lib/caja/extensions-2.0/**")))))
-- 
2.34.0

0015-gnu-caja-Update-to-1.26.0-and-use-G-expression.patch0000644000175000017460000000462014206265675021332 0ustar  fengusersFrom a89f358a2d4b9144c921caeb334d139f8f9be545 Mon Sep 17 00:00:00 2001
From: Feng Shu <tumashu@163.com>
Date: Fri, 25 Feb 2022 20:42:11 +0800
Subject: [PATCH 15/34] gnu: caja: Update to 1.26.0 and use G-expression.

* gnu/packages/mate.scm (caja): Update to 1.26.0 and use G-expression.
---
 gnu/packages/mate.scm | 38 +++++++++++++++++++-------------------
 1 file changed, 19 insertions(+), 19 deletions(-)

diff --git a/gnu/packages/mate.scm b/gnu/packages/mate.scm
index 3a98138511..db095a977c 100644
--- a/gnu/packages/mate.scm
+++ b/gnu/packages/mate.scm
@@ -772,7 +772,7 @@ (define-public atril
 (define-public caja
   (package
     (name "caja")
-    (version "1.24.0")
+    (version "1.26.0")
     (source
      (origin
        (method url-fetch)
@@ -780,27 +780,27 @@ (define-public caja
                            name "-" version ".tar.xz"))
        (sha256
         (base32
-         "1cnfy481hcwjv3ia3kw0d4h7ga8cng0pqm3z349v4qcmfdapmqc0"))))
+         "1m0ai2r8b2mvlr8bqj9n6vg1pwzlwa46fqpq206wgyx5sgxac052"))))
     (build-system glib-or-gtk-build-system)
     (arguments
-     `(#:configure-flags '("--disable-update-mimedb")
-       #:tests? #f ; tests fail even with display set
-       #:phases
-       (modify-phases %standard-phases
-         (add-before 'check 'pre-check
-           (lambda _
-             ;; Tests require a running X server.
-             (system "Xvfb :1 &")
-             (setenv "DISPLAY" ":1")
-             ;; For the missing /etc/machine-id.
-             (setenv "DBUS_FATAL_WARNINGS" "0")
-             #t)))))
+     (list
+      #:configure-flags #~(list "--disable-update-mimedb")
+      #:tests? #f ; tests fail even with display set
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-before 'check 'pre-check
+            (lambda _
+              ;; Tests require a running X server.
+              (system "Xvfb :1 &")
+              (setenv "DISPLAY" ":1")
+              ;; For the missing /etc/machine-id.
+              (setenv "DBUS_FATAL_WARNINGS" "0"))))))
     (native-inputs
-     `(("pkg-config" ,pkg-config)
-       ("intltool" ,intltool)
-       ("glib:bin" ,glib "bin")
-       ("xorg-server" ,xorg-server)
-       ("gobject-introspection" ,gobject-introspection)))
+     (list pkg-config
+           intltool
+           `(,glib "bin")
+           xorg-server
+           gobject-introspection))
     (inputs
      (list exempi
            gtk+
-- 
2.34.0

